@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """projit.cli: provides entry point main()."""
-
+import pandas as pd
 import sys
 import os
 
@@ -12,6 +12,8 @@ from .utils import get_properties
 from .utils import write_properties
 from .projit import load as projit_load
 from .projit import init as projit_init
+
+from projit import __version__
  
 def main():
     if len(sys.argv) < 2:
@@ -20,49 +22,65 @@ def main():
         exit(1)
     else:
         cmd = sys.argv[1]
+        if len(sys.argv) == 2:
+            if sys.argv[1] == "-v":
+                print(" Version:", __version__)
+                exit(1)
+            elif sys.argv[1] == "-h":
+                print_usage(sys.argv)
+                exit(1)
+        
         if cmd == "init":
             init(sys.argv)
-        else:
-            config_path = locate_projit_config() 
-            #print("CONFIG:", config_path)
-            if config_path=="":
-                print("This is not a projit project. Please use '>projit init <Project_Name>'")
+            exit(1)
+
+        config_path = locate_projit_config() 
+        if config_path=="":
+            print(" ERROR: This is not a projit project.")
+            print("        Please initialise the project first.")
+            print(" > projit init <PROJECT NAME>")
+            exit(1)
+
+        project = projit_load(config_path)
+
+        if cmd == "update":
+            update(project)
+            exit(1)
+        if cmd == "status":
+            project_status(project)
+            exit(1)
+        if cmd == "render":
+            if len(sys.argv) < 3:
+                print(" ERROR: Rendering a project requires a path for output file.")
+                exit(1)
+            else:
+                path = sys.argv[2]
+                render_doc(project, path)
+                exit(1)
+        if cmd == "list":
+            if len(sys.argv) < 3:
+                print(" ERROR: MISSING ARGUMENTS")
+                print_usage(sys.argv)
+                exit(1)
+            else:
+                subcmd = sys.argv[2]
+                list(subcmd, project)
+                exit(1)
+        if cmd == "add":
+            if len(sys.argv) < 5:
+                print(" ERROR: MISSING ARGUMENTS")
+                print_usage(sys.argv)
+                exit(1)
+            else:
+                subcmd = sys.argv[2]
+                add(subcmd, project, sys.argv)
                 exit(1)
 
-            project = projit_load(config_path)
-
-            if cmd == "update":
-                update(project)
-            if cmd == "status":
-                project_status(project)
-            if cmd == "render":
-                if len(sys.argv) < 3:
-                    print("ERROR: Rendering a project requires a path for output file.")
-                    exit(1)
-                else:
-                    path = sys.argv[2]
-                    render_doc(project, path)
-            if cmd == "list":
-                if len(sys.argv) < 3:
-                    print("ERROR: MISSING ARGUMENTS")
-                    print_usage(sys.argv)
-                    exit(1)
-                else:
-                    subcmd = sys.argv[2]
-                    list(subcmd, project)
-            if cmd == "add":
-                if len(sys.argv) < 5:
-                    print("ERROR: MISSING ARGUMENTS")
-                    print_usage(sys.argv)
-                    exit(1)
-                else:
-                    subcmd = sys.argv[2]
-                    add(subcmd, project, sys.argv)
-
+        print(" ERROR: UNKNOWN ARGUMENTS")
+        print_usage(sys.argv)
 
 ##########################################################################################        
 def init(argv):
-    #print("YOU WANT TO INITIALISE")
     config_file = locate_projit_config()
     if config_file != "":
         print("ERROR: Project exists. Run `projit update` to change details ")
@@ -127,6 +145,12 @@ def list(subcmd, project):
         for exp in project.experiments:
             print(" ", exp[0], filler(len(exp[0]), long_key+1 ), exp[1] )
         print("")
+    elif subcmd == "results":
+        rez = project.get_results()
+        print(" ___Results_____________________________________")
+        pd.set_option('expand_frame_repr', False)
+        pd.set_option('display.max_columns', 999)
+        print(rez)
     else:
         print("ERROR: Unrecognised SUBCOMMAND: %s" % subcmd)
         exit(1)
@@ -152,20 +176,24 @@ def add(subcmd, project, args):
 ##########################################################################################        
 def print_usage(args):
     """ Command line application usage instrutions. """
-    print("USAGE ")
-    print(args[0], " <COMMAND> [<SUBCOMMAND>] [<PARAMS>*]")
-    print("  <COMMAND>     - Core Task: init, status, list, add, run, render")
-    print("  <SUBCOMMAND>  - (OPTIONAL) Dependant on COMMAND: dataset, experiment")
-    print("  <PARAMS>      - (OPTIONAL) Dependant on task, names and paths")
+    print(" USAGE ")
+    print(" ", args[0], " [OPTIONS] <COMMAND> [<SUBCOMMAND>] [<PARAMS>*]")
+    print("   <COMMAND>     - CORE TASK TO PERFORM: [init | upate | status | add | list | render]")
+    print("   <SUBCOMMAND>  - (OPTIONAL) Dependant on COMMAND: [dataset | experiment | results]")
+    print("   <PARAMS>      - (OPTIONAL) Dependant on COMMAND: Usually names and paths")
+    print("   [OPTIONS]")
+    print("      -v             - Print version")
+    print("      -h             - Print this usage help")
     print("")
-    print("COMMON PATTERN")
-    print(args[0], "init 'Project name'")
-    print(args[0], "status")
-    print(args[0], "add dataset train data/train.csv")
-    print(args[0], "add dataset test data/test.csv")
-    print(args[0], "add experiment exploration exp/explore.ipynb")
-    print(args[0], "list datasets")
+    print("   COMMON PATTERNS")
+    print("   ", args[0], "init 'Project name'")
+    print("   ", args[0], "status")
+    print("   ", args[0], "add dataset train data/train.csv")
+    print("   ", args[0], "add dataset test data/test.csv")
+    print("   ", args[0], "add experiment exploration exp/explore.ipynb")
+    print("   ", args[0], "list datasets")
+    print("   ", args[0], "list experiments")
+    print("   ", args[0], "list results")
     print("")
 
-
 ##########################################################################################        
